Learn R Programming

bmk (version 1.0)

HWconverg1: Hellinger distance within consecutive batches of MCMC samples.

Description

Determine if a specific chain has converged. This takes a chain and divides it into batches and calculates the Hellinger distance between consecutive batches.

Usage

HWconverg1(chain1, batchsize1 = 1000)

Arguments

chain1
A vector of a single MCMC chain.
batchsize1
An integer that defines the size of the batches.

Value

c2 A vector of Hellinger distances between consecutive batches.