Rdocumentation
powered by
Learn R Programming
bmk (version 1.0)
HBconverg1: Hellinger distance between distributions
Description
This computes the Hellinger distance for all pairwise combinations of MCMC chains.
Usage
HBconverg1(chains1)
Arguments
chains1
A matrix of MCMC for the same variable. Each column corresponds to a different chain.
Value
c2 A vector containing the minimum and maximum Hellinger distances across all pairwise comparisons.